@@ -26,7 +26,7 @@ View contains three part:
 #include "../jammo-mentor.h"
 #include "../jammo-track-view.h"
 #include "../jammo-miditrack-view.h"
-
+#include "../../cem/cem.h"
 
 #include "sequencer.h"
 #include "sequencer_loop.h"
@@ -551,7 +551,9 @@ void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer us
 }
 
 
-
+void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none){
+	cem_add_to_log("sequencer_render_button_pressed",LOG_USER_ACTION);
+}
 
 void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Metronome pressed\n");
