@@ -114,19 +114,22 @@ gint jammo_sample_button_get_loop_id(JammoSampleButton* sample_button) {
 }
 
 void jammo_sample_button_set_loop_id(JammoSampleButton* sample_button, gint loop_id) {
-
 	sample_button->priv->loop_id = loop_id;
+	g_object_notify(G_OBJECT(sample_button), "loop-id");
 }
 
 void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, const gchar* image_filename) {
 	ClutterActor* texture;
+	gchar* filename;
 	
 	if (!sample_button->priv->image_filename ||
 	    strcmp(sample_button->priv->image_filename, image_filename)) {
 		g_free(sample_button->priv->image_filename);
 		sample_button->priv->image_filename = g_strdup(image_filename);
 
-		texture = clutter_texture_new_from_file(image_filename, NULL);
+		filename = tangle_lookup_filename(image_filename);
+		texture = clutter_texture_new_from_file(filename, NULL);
+		g_free(filename);
 		if (!texture) {
 			g_warning("Could not create a texture from a file '%s', ignored.", image_filename);
 			
@@ -142,14 +145,18 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 }
 
 void jammo_sample_button_set_sample_filename(JammoSampleButton* sample_button, const gchar* sample_filename) {
+	gchar* filename;
+	
 	if (!sample_button->priv->sample ||
 	    !jammo_sample_get_filename(sample_button->priv->sample) ||
 	    strcmp(jammo_sample_get_filename(sample_button->priv->sample), sample_filename)) {
 		if (sample_button->priv->sample) {
 			g_object_unref(sample_button->priv->sample);
 		}
-		sample_button->priv->sample = jammo_sample_new_from_file_with_sequencer(sample_filename, sample_button->priv->sequencer);
+		filename = tangle_lookup_filename(sample_filename);
+		sample_button->priv->sample = jammo_sample_new_from_file_with_sequencer(filename, sample_button->priv->sequencer);
 		g_object_ref(sample_button->priv->sample);
+		g_free(filename);
 
 		g_object_notify(G_OBJECT(sample_button), "sample-filename");
 		g_object_notify(G_OBJECT(sample_button), "sample");
