@@ -582,32 +582,49 @@ static gfloat freq_of_quarter_tone[] = { 32.703201, 33.661480, 34.647835, 35.663
 7677.175781, 7902.134277
 };
 
-/*We roll over above frequence table (sorted) and when value from table is bigger
-than parameter, we check which one is nearer (which direction to round)*/
+/*Simple binary search from frequence table (sorted).
+Most of the time asked value is not in table -> we check which
+one is nearer (which direction to round)*/
 static gfloat freq_rounding(gfloat freq){
- int i; //i starts from 1. All too low values are then rounded to table[0]
- for (i=1;i<NUMBER_OF_OCTAVES*NUMBER_OF_NOTES;i++){//roll over frequence table above (they are sorted)
-  if (freq_of_note[i]>freq){                //continue until table has bigger than parameter
-    gfloat delta  =freq_of_note[i]-freq;    //this is delta of parameter and bigger value from table
-    gfloat delta2 =freq-freq_of_note[i-1];  //this is delta of parameter and smaller value from table
-    return delta<delta2?freq_of_note[i]:freq_of_note[i-1]; //return value, which is nearer to parameter
-  }
- }
- return 8000; //We could also return biggest value from table.
+	int min = 1; //prevents overflow
+	int max = NUMBER_OF_OCTAVES*NUMBER_OF_NOTES;
+	int mid = min + ((max-min)/2);
+
+	while  ((freq != freq_of_note[mid]) && min < max) {
+		if (freq > freq_of_note[mid]) {
+			min = mid +1;
+			}
+		else {
+		max = mid -1;
+		}
+	mid = min + ((max-min)/2);
+	}
+
+	gfloat delta  =freq_of_note[mid]-freq;    //this is delta of parameter and bigger value from table
+	gfloat delta2 =freq-freq_of_note[mid-1];  //this is delta of parameter and smaller value from table
+	return delta<delta2?freq_of_note[mid]:freq_of_note[mid-1]; //return value, which is nearer to parameter
 }
 
 /* similar rounding for new notes */
 /* this is done instantly. rounding to nearest quarter tone */
 static gfloat freq_rounding_new_note(gfloat freq){
- int i; //i starts from 1. All too low values are then rounded to table[0]
- for (i=1;i<NUMBER_OF_OCTAVES*NUMBER_OF_NOTES*2-1;i++){//roll over frequence table above (they are sorted)
-  if (freq_of_quarter_tone[i]>freq){                //continue until table has bigger than parameter
-    gfloat delta  =freq_of_quarter_tone[i]-freq;    //this is delta of parameter and bigger value from table
-    gfloat delta2 =freq-freq_of_quarter_tone[i-1];  //this is delta of parameter and smaller value from table
-    return delta<delta2?freq_of_quarter_tone[i]:freq_of_quarter_tone[i-1]; //return value, which is nearer to parameter
-  }
- }
- return 8000; //We could also return biggest value from table.
+	int min = 1; //prevents overflow
+	int max = NUMBER_OF_OCTAVES*NUMBER_OF_NOTES*2-1;
+	int mid = min + ((max-min)/2);
+
+	while  ((freq != freq_of_quarter_tone[mid]) && min < max) {
+		if (freq > freq_of_quarter_tone[mid]) {
+			min = mid +1;
+		}
+		else {
+			max = mid -1;
+		}
+	mid = min + ((max-min)/2);
+	}
+
+	gfloat delta  =freq_of_quarter_tone[mid]-freq;    //this is delta of parameter and bigger value from table
+	gfloat delta2 =freq-freq_of_quarter_tone[mid-1];  //this is delta of parameter and smaller value from table
+	return delta<delta2?freq_of_quarter_tone[mid]:freq_of_quarter_tone[mid-1]; //return value, which is nearer to parameter
 }
 
 // a function for initializing parameters when starting to play a new note
