@@ -13,18 +13,7 @@
 #include "jammo-meam-private.h"
 #include <sys/time.h>
 #include "jammo-midi.h"
-
-/*
-	#include "../chum/chum.h" //because of DATA_DIR
-	
-	MEAM must not include CHUM! Please, move global definitions
-	to some global header file.
-	
-	This is temporary hack:
-*/
-#define DATA_DIR "/opt/jammo"
-/* Actually, DATA_DIR should be defined using configure script... */
-
+#include "../configure.h" // for DATA_DIR
 
 
 #define INSTRUMENT_FOLDER DATA_DIR "/virtual-instruments/"
