@@ -49,7 +49,9 @@ struct _JammoSequencerPrivate {
 	gchar* pitch;
 
 	GstElement* pipeline;
+	GstElement* bin;
 	GstElement* adder;
+	GstElement* queue;
 	GstElement* audiosink;
 	GstElement* audioconvert;
 	GstElement* vorbisenc;
@@ -68,6 +70,7 @@ static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer
 static GstElement* create_element(const gchar* name);
 static gboolean setup_audiosink(JammoSequencer* sequencer);
 static gboolean setup_filesink(JammoSequencer* sequencer, const gchar* filename);
+static void start_playing(JammoSequencer* sequencer);
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
@@ -183,8 +186,7 @@ void jammo_sequencer_set_pitch(JammoSequencer* sequencer, const gchar* pitch) {
  */
 void jammo_sequencer_play(JammoSequencer* sequencer) {
 	if (sequencer->priv->ready) {
-		gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PLAYING);
-		g_signal_emit(sequencer, signals[STARTED], 0);
+		start_playing(sequencer);
 	}
 	sequencer->priv->playing = TRUE;
 }
@@ -273,11 +275,11 @@ void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 		_jammo_track_set_pitch(track, sequencer->priv->pitch);
 
 		element = gst_element_factory_make("audioconvert", NULL);
-		gst_bin_add(GST_BIN(sequencer->priv->pipeline), element);
-		if (_jammo_track_setup_element(track, GST_BIN(sequencer->priv->pipeline), element)) {
+		gst_bin_add(GST_BIN(sequencer->priv->bin), element);
+		if (_jammo_track_setup_element(track, GST_PIPELINE(sequencer->priv->pipeline), GST_BIN(sequencer->priv->bin), element)) {
 			gst_element_link(element, sequencer->priv->adder);
 		} else {
-			gst_bin_remove(GST_BIN(sequencer->priv->pipeline), element);
+			gst_bin_remove(GST_BIN(sequencer->priv->bin), element);
 		}
 
 		sequencer->priv->duration = 0;
@@ -393,11 +395,11 @@ gboolean jammo_sequencer_set_output_filename(JammoSequencer* sequencer, const gc
 		} else {
 			/* Destroy current sinks. */
 			if (sequencer->priv->audiosink) {
-				gst_bin_remove(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audiosink);
+				gst_bin_remove_many(GST_BIN(sequencer->priv->bin), sequencer->priv->queue, sequencer->priv->audiosink, NULL);
 				sequencer->priv->audiosink = NULL;
 			}
 			if (sequencer->priv->filesink) {
-				gst_bin_remove_many(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
+				gst_bin_remove_many(GST_BIN(sequencer->priv->bin), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
 				sequencer->priv->filesink = NULL;
 			}
 
@@ -598,8 +600,12 @@ static void jammo_sequencer_init(JammoSequencer* sequencer) {
 	gst_bus_add_watch(bus, on_bus_message, sequencer);
 	gst_object_unref (bus);
 
+	sequencer->priv->bin = gst_bin_new(NULL);
+	g_object_set(sequencer->priv->bin, "async-handling", TRUE, NULL);
+	gst_bin_add(GST_BIN(sequencer->priv->pipeline), sequencer->priv->bin);
+
 	if ((sequencer->priv->adder = create_element("adder"))) {
-		gst_bin_add(GST_BIN(sequencer->priv->pipeline), sequencer->priv->adder);
+		gst_bin_add(GST_BIN(sequencer->priv->bin), sequencer->priv->adder);
 		setup_audiosink(sequencer);
 	}
 }
@@ -673,8 +679,7 @@ static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer
 				sequencer->priv->ready = TRUE;
 				g_object_notify(G_OBJECT(sequencer), "ready");
 				if (sequencer->priv->playing) {
-					gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PLAYING);
-					g_signal_emit(sequencer, signals[STARTED], 0);
+					start_playing(sequencer);
 				}
 			}
 		}	
@@ -694,10 +699,12 @@ static GstElement* create_element(const gchar* name) {
 static gboolean setup_audiosink(JammoSequencer* sequencer) {
 	gboolean retvalue = FALSE;
 	
-	if ((sequencer->priv->audiosink = create_element("autoaudiosink"))) {
-		gst_bin_add(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audiosink);
-		if (!gst_element_link(sequencer->priv->adder, sequencer->priv->audiosink)) {
-			g_critical("Failed to link audiosink.");
+	if ((sequencer->priv->queue = create_element("queue")) &&
+	    (sequencer->priv->audiosink = create_element("pulsesink"))) {
+	    	g_object_set(sequencer->priv->audiosink, "buffer-time", 800000, NULL);
+		gst_bin_add_many(GST_BIN(sequencer->priv->bin), sequencer->priv->queue, sequencer->priv->audiosink, NULL);
+		if (!gst_element_link_many(sequencer->priv->adder, sequencer->priv->queue, sequencer->priv->audiosink, NULL)) {
+			g_critical("Failed to link pulsesink.");
 		} else {
 			retvalue = TRUE;
 		}
@@ -716,7 +723,7 @@ static gboolean setup_filesink(JammoSequencer* sequencer, const gchar* filename)
 		g_object_set(G_OBJECT(sequencer->priv->vorbisenc), "quality", OGGQUALITY, NULL);
 		g_object_set(G_OBJECT(sequencer->priv->filesink), "location", filename, NULL);
 
-		gst_bin_add_many(GST_BIN(sequencer->priv->pipeline), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
+		gst_bin_add_many(GST_BIN(sequencer->priv->bin), sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL);
 		if (!gst_element_link_many(sequencer->priv->adder, sequencer->priv->audioconvert, sequencer->priv->vorbisenc, sequencer->priv->oggmux, sequencer->priv->filesink, NULL)) {
 			g_critical("Failed to link filesink.");
 		} else {
@@ -726,3 +733,13 @@ static gboolean setup_filesink(JammoSequencer* sequencer, const gchar* filename)
 
 	return retvalue;
 }
+
+static void start_playing(JammoSequencer* sequencer) {
+	GstState state, pending;
+	
+	gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PAUSED);
+	gst_element_get_state(sequencer->priv->bin, &state, &pending, GST_CLOCK_TIME_NONE);
+
+	gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PLAYING);
+	g_signal_emit(sequencer, signals[STARTED], 0);
+}
