@@ -28,6 +28,8 @@ struct _JammoSliderTrackPrivate {
 	GstElement* slider;
 	GstElement* filter;
 	int slider_type;
+	gfloat tempo_scale;
+	gint pitch_shift;
 	struct timeval creation_time; //Not used yet
 };
 
@@ -39,7 +41,9 @@ static guint signals[LAST_SIGNAL];
 
 
 JammoSliderTrack* jammo_slider_track_new(JammoSliderType slider_type) {
-	return JAMMO_SLIDER_TRACK(g_object_new(JAMMO_TYPE_SLIDER_TRACK,"slider-type",slider_type,NULL));
+	JammoSliderTrack * slider_track = JAMMO_SLIDER_TRACK(g_object_new(JAMMO_TYPE_SLIDER_TRACK,"slider-type",slider_type,NULL));
+	slider_track->priv->slider=NULL;
+	return slider_track;
 }
 
 static guint64 jammo_slider_track_get_duration(JammoTrack* track) {
@@ -128,41 +132,44 @@ static gboolean jammo_slider_track_receive_message(JammoTrack* track, GstMessage
 
 static void jammo_slider_track_set_tempo(JammoTrack* track, guint tempo) {
 	JammoSliderTrack* slider_track;
-	gfloat tempo_scale;
 	
 	slider_track = JAMMO_SLIDER_TRACK(track);
 
 	if (tempo==0) {
-		tempo_scale=1.0;
+		slider_track->priv->tempo_scale=1.0;
 	}
 	else {
-		tempo_scale=(gfloat)tempo / DEFAULT_TEMPO;
+		slider_track->priv->tempo_scale=(gfloat)tempo / DEFAULT_TEMPO;
+	}
+	if (slider_track->priv->slider) {
+		g_object_set(slider_track->priv->slider, "tempo-scale", slider_track->priv->tempo_scale, NULL);
 	}
-	g_object_set(slider_track->priv->slider, "tempo-scale", tempo_scale, NULL);
 	
 }
 
 static void jammo_slider_track_set_pitch(JammoTrack* track, const gchar* pitch) {
 	JammoSliderTrack* slider_track;
-	gint pitch_shift=0;
 	
 	slider_track = JAMMO_SLIDER_TRACK(track);
-	if (pitch==NULL) pitch_shift=0;
-	else if (strcmp(pitch, "C")==0) pitch_shift=0;
-	else if (strcmp(pitch, "C#")==0) pitch_shift=1;
-	else if (strcmp(pitch, "D")==0) pitch_shift=2;
-	else if (strcmp(pitch, "D#")==0) pitch_shift=3;
-	else if (strcmp(pitch, "E")==0) pitch_shift=4;
-	else if (strcmp(pitch, "F")==0) pitch_shift=5;
-	else if (strcmp(pitch, "F#")==0) pitch_shift=6;
-	else if (strcmp(pitch, "G")==0) pitch_shift=7;
-	else if (strcmp(pitch, "G#")==0) pitch_shift=8;
-	else if (strcmp(pitch, "A")==0) pitch_shift=9;
-	else if (strcmp(pitch, "A#")==0) pitch_shift=10;
-	else if (strcmp(pitch, "B")==0) pitch_shift=11;
-	else pitch_shift=0;
-	
-	g_object_set(slider_track->priv->slider, "pitch-shift", pitch_shift, NULL);	
+
+	if (pitch==NULL) slider_track->priv->pitch_shift=0;
+	else if (strcmp(pitch, "C")==0) slider_track->priv->pitch_shift=0;
+	else if (strcmp(pitch, "C#")==0) slider_track->priv->pitch_shift=1;
+	else if (strcmp(pitch, "D")==0) slider_track->priv->pitch_shift=2;
+	else if (strcmp(pitch, "D#")==0) slider_track->priv->pitch_shift=3;
+	else if (strcmp(pitch, "E")==0) slider_track->priv->pitch_shift=4;
+	else if (strcmp(pitch, "F")==0) slider_track->priv->pitch_shift=5;
+	else if (strcmp(pitch, "F#")==0) slider_track->priv->pitch_shift=6;
+	else if (strcmp(pitch, "G")==0) slider_track->priv->pitch_shift=7;
+	else if (strcmp(pitch, "G#")==0) slider_track->priv->pitch_shift=8;
+	else if (strcmp(pitch, "A")==0) slider_track->priv->pitch_shift=9;
+	else if (strcmp(pitch, "A#")==0) slider_track->priv->pitch_shift=10;
+	else if (strcmp(pitch, "B")==0) slider_track->priv->pitch_shift=11;
+	else slider_track->priv->pitch_shift=0;
+
+	if (slider_track->priv->slider) {
+		g_object_set(slider_track->priv->slider, "pitch-shift", slider_track->priv->pitch_shift, NULL);
+	}
 }
 
 static GstElement* jammo_slider_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
@@ -209,6 +216,8 @@ static GstElement* jammo_slider_track_setup_playing_element(JammoPlayingTrack* p
 	}
 	
 	g_object_set(G_OBJECT(slider_track->priv->slider), "recording", FALSE, NULL);
+	g_object_set(G_OBJECT(slider_track->priv->slider), "pitch-shift", slider_track->priv->pitch_shift, NULL);
+	g_object_set(G_OBJECT(slider_track->priv->slider), "tempo-scale", slider_track->priv->tempo_scale, NULL);
 	
 	gst_bin_add_many(bin, slider_track->priv->slider, slider_track->priv->filter, NULL);
 	gst_element_link(slider_track->priv->slider, slider_track->priv->filter);
